@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2020 Averbis GmbH.
+# Copyright (c) 2021 Averbis GmbH.
 #
 # This file is part of Averbis Python API.
 # See https://www.averbis.com for further info.
@@ -16,6 +16,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .core import Client, Project, Pipeline, Result, Terminology, DocumentCollection
+#
+from .core import Client, Project, Pipeline, Result, Terminology, DocumentCollection, Pear, Process
 
-__all__ = ["Client", "Project", "Pipeline", "Result", "Terminology", "DocumentCollection"]
+__all__ = [
+    "Client",
+    "Project",
+    "Pipeline",
+    "Result",
+    "Terminology",
+    "DocumentCollection",
+    "Pear",
+    "Process",
+]
